// Copyright 2007-2008 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using Microsoft.Win32;

namespace AudioTagR
{
    public partial class NewItem : Form
    {
        private string m_lookup;

        private NewItem()
        {
            InitializeComponent();

            using (RegistryKey key = Registry.CurrentUser.CreateSubKey(@"SOFTWARE\OpenNETCF\AudioTagR"))
            {
                m_lookup = (string)key.GetValue("LookupURL", "http://www.freedb.org/freedb_search.php");
            }
        }

        void item_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Return:
                    this.DialogResult = DialogResult.OK;
                    this.Close();
                    break;
                case Keys.Escape:
                    this.DialogResult = DialogResult.Cancel;
                    this.Close();
                    break;
            }
        }

        public NewItem(bool getArtist, bool getAlbum, bool getYear, bool getTitle, bool getTrackNumber)
            : this()
        {
            BuildForm(getArtist, getAlbum, getYear, getTitle, getTrackNumber);
            graceNote.LinkClicked += new LinkLabelLinkClickedEventHandler(graceNote_LinkClicked);
        }

        void graceNote_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            ProcessStartInfo info = new ProcessStartInfo(m_lookup);
            info.UseShellExecute = true;
            Process.Start(info);
        }

        internal TextBox artist = new TextBox();
        internal TextBox album = new TextBox();
        internal TextBox year = new TextBox();
        internal TextBox title = new TextBox();
        internal TextBox trackNumber = new TextBox();

        internal Label artistLabel = new Label();
        internal Label albumLabel = new Label();
        internal Label yearLabel = new Label();
        internal Label titleLabel = new Label();
        internal Label trackNumberLabel = new Label();

        private void BuildForm(bool getArtist, bool getAlbum, bool getYear, bool getTitle, bool getTrackNumber)
        {
            int labelLeft = 12;
            int labelTop = 28;
            int textLeft = 58;
            int textTop = 25;
            int spacing = 26;

            int groupHeight = 63;

            Size textSize = new Size(209, 20);
            Size labelSize = new Size(30, 13);

            int index = 0;
            TextBox lastInput = null;

            this.SuspendLayout();
            group.SuspendLayout();

            #region --- artist ---
            if (getArtist)
            {
                artist.Location = new System.Drawing.Point(textLeft, textTop + (spacing * index));
                artist.Name = "artist";
                artist.Size = textSize;
                artist.TabIndex = index;

                artistLabel.AutoSize = true;
                artistLabel.Location = new System.Drawing.Point(labelLeft, labelTop + (spacing * index));
                artistLabel.Name = "artistLabel";
                artistLabel.Size = labelSize;
                artistLabel.Text = "Artist";

                group.Controls.Add(artist);
                group.Controls.Add(artistLabel);

                index++;
                groupHeight += spacing;
                lastInput = artist;
            }
            #endregion

            #region --- album ---
            if (getAlbum)
            {
                album.Location = new System.Drawing.Point(textLeft, textTop + (spacing * index));
                album.Name = "album";
                album.Size = textSize;
                album.TabIndex = index;

                albumLabel.AutoSize = true;
                albumLabel.Location = new System.Drawing.Point(labelLeft, labelTop + (spacing * index));
                albumLabel.Name = "albumLabel";
                albumLabel.Size = labelSize;
                albumLabel.Text = "Album";

                group.Controls.Add(album);
                group.Controls.Add(albumLabel);

                index++;
                groupHeight += spacing;
                lastInput = album;
            }
            #endregion

            #region --- year ---
            if (getYear)
            {
                year.Location = new System.Drawing.Point(textLeft, textTop + (spacing * index));
                year.Name = "year";
                year.Size = textSize;
                year.TabIndex = index;

                yearLabel.AutoSize = true;
                yearLabel.Location = new System.Drawing.Point(labelLeft, labelTop + (spacing * index));
                yearLabel.Name = "yearLabel";
                yearLabel.Size = labelSize;
                yearLabel.Text = "Year";

                group.Controls.Add(year);
                group.Controls.Add(yearLabel);

                index++;
                groupHeight += spacing;
                lastInput = year;
            }
            #endregion

            #region --- title ---
            if (getTitle)
            {
                title.Location = new System.Drawing.Point(textLeft, textTop + (spacing * index));
                title.Name = "title";
                title.Size = textSize;
                title.TabIndex = index;

                titleLabel.AutoSize = true;
                titleLabel.Location = new System.Drawing.Point(labelLeft, labelTop + (spacing * index));
                titleLabel.Name = "titleLabel";
                titleLabel.Size = labelSize;
                titleLabel.Text = "Title";

                group.Controls.Add(title);
                group.Controls.Add(titleLabel);

                index++;
                groupHeight += spacing;
                lastInput = title;
            }
            #endregion

            #region --- track number ---
            if (getTrackNumber)
            {
                trackNumber.Location = new System.Drawing.Point(textLeft, textTop + (spacing * index));
                trackNumber.Name = "trackNumber";
                trackNumber.Size = textSize;
                trackNumber.TabIndex = index;

                trackNumberLabel.AutoSize = true;
                trackNumberLabel.Location = new System.Drawing.Point(labelLeft, labelTop + (spacing * index));
                trackNumberLabel.Name = "trackNumberLabel";
                trackNumberLabel.Size = labelSize;
                trackNumberLabel.Text = "Track #";

                group.Controls.Add(trackNumber);
                group.Controls.Add(trackNumberLabel);

                index++;
                groupHeight += spacing;
                lastInput = trackNumber;
            }
            #endregion

            cancel.Top = ok.Top = textTop + (spacing * index);
            group.Height = groupHeight;
            graceNote.Top = cancel.Top + 10;

            this.Height = groupHeight + 15;

            group.ResumeLayout();
            this.ResumeLayout();

            if (lastInput != null)
            {
                lastInput.KeyDown += new KeyEventHandler(lastInput_KeyDown);
            }
        }

        void lastInput_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Enter:
                    DialogResult = DialogResult.OK;
                    this.Close();
                    return;
                case Keys.Escape:
                    DialogResult = DialogResult.Cancel;
                    this.Close();
                    return;
            }
        }
    }
}