// Copyright 2007-2012 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.

using System;
using System.IO;
using System.Diagnostics;

namespace OpenNETCF.Media.MP3.Frames
{
    internal static class FrameFactory
    {
        public static ID3Frame GetFrame(FileStream stream, int maxPos)
        {
            byte[] frameData = ID3Frame.GetFrameBytesFromStream(stream, maxPos);

            if (frameData == null) return null;

            string id = ID3Frame.IDFromBytes(frameData);
            ID3Frame frame;
            switch (id)
            {
                case "TIT2":
                    frame = new TitleFrame(frameData);
                    break;
                case "TALB":
                    frame = new AlbumFrame(frameData);
                    break;
                case "TPUB":
                    frame = new PublisherFrame(frameData);
                    break;
                case "TYER":
                    frame = new YearFrame(frameData);
                    break;
                case "TRCK":
                    frame = new TrackFrame(frameData);
                    break;
                case "TCON":
                    frame = new ContentTypeFrame(frameData);
                    break;
                case "TPE2":
                    frame = new ArtistFrame(frameData);
                    break;
                default:
                    if (id.Replace("\0", string.Empty) == string.Empty)
                    {
                        // we're in an empty buffer - no more frames will follow
                        return null;
                    }

                    Debug.WriteLine("Unknown frame type: " + id);
                    frame = new UnknownFrame(frameData);
                    break;
            }

            if (frame is TextFrame)
            {
                if (frame is ContentTypeFrame)
                {
                    Debug.WriteLine(string.Format("Genre: {0}", ((ContentTypeFrame)frame).Genre.ToString()));
                }
                else
                {
                    Debug.WriteLine(string.Format("{0}: {1}", frame.GetType().Name.Replace("Frame", ""), ((TextFrame)frame).Text));
                }
            }

            return frame;
        }
    }
}
