// Copyright 2007-2012 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Text;

namespace OpenNETCF.Media.MP3.Frames
{
    internal abstract class TextFrame : ID3Frame
    {
        private const int ENCODING_OFFSET = HEADER_LENGTH;
        private const int ENCODING_LENGTH = 1;
        private const int TEXT_OFFSET = ENCODING_OFFSET + ENCODING_LENGTH;

        internal abstract string GetFrameIdentifier();

        internal TextFrame()
            : base(new byte[HEADER_LENGTH])
        {
            this.ID = GetFrameIdentifier();
        }

        public TextFrame(byte[] data)
            : base(data)
        {
        }

        public byte EncodingByte
        {
            get { return m_data[ENCODING_OFFSET]; }
        }

        public string Text
        {
            get { return Encoding.ASCII.GetString(m_data, TEXT_OFFSET, m_data.Length - TEXT_OFFSET); }
            set
            {
                byte[] textBytes = Encoding.ASCII.GetBytes(value);
                byte[] newData = new byte[HEADER_LENGTH + ENCODING_LENGTH + textBytes.Length];

                Buffer.BlockCopy(m_data, 0, newData, 0, HEADER_LENGTH);
                Buffer.BlockCopy(textBytes, 0, newData, TEXT_OFFSET, textBytes.Length);

                m_data = newData;

                UpdateLength(textBytes.Length + ENCODING_LENGTH);
            }
        }
    }
}
