// Copyright 2007-2012 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Text;

namespace OpenNETCF.Media.MP3.Frames
{
    internal class TitleFrame : TextFrame
    {
        public TitleFrame()
            : base()
        { 
        }

        public TitleFrame(byte[] data)
            : base(data)
        {
        }

        internal override string GetFrameIdentifier()
        {
            return "TIT2";
        }
    }

    internal class AlbumFrame : TextFrame
    {
        public AlbumFrame()
            : base()
        { 
        }

        public AlbumFrame(byte[] data)
            : base(data)
        {
        }


        internal override string GetFrameIdentifier()
        {
            return "TALB";
        }
    }

    internal class PublisherFrame : TextFrame
    {
        public PublisherFrame()
            : base()
        { 
        }

        public PublisherFrame(byte[] data)
            : base(data)
        {
        }

        internal override string GetFrameIdentifier()
        {
            return "TPUB";
        }
    }

    internal class YearFrame : TextFrame
    {
        public YearFrame()
            : base()
        { 
        }

        public YearFrame(byte[] data)
            : base(data)
        {
        }

        internal override string GetFrameIdentifier()
        {
            return "TYER";
        }
    }

    internal class TrackFrame : TextFrame
    {
        public TrackFrame()
            : base()
        { 
        }

        public TrackFrame(byte[] data)
            : base(data)
        {
        }

        internal override string GetFrameIdentifier()
        {
            return "TRCK";
        }
    }

    internal class ContentTypeFrame : TextFrame
    {
        public ContentTypeFrame(byte[] data)
            : base(data)
        {
        }

        public Genre Genre
        {
            get
            {
                int start = Text.IndexOf('(');
                int end = Text.IndexOf(')');
                
                if(end <= start) return Genre.Unknown;
                string s = Text.Substring(start + 1, end-start-1);
                try
                {
                    int g = int.Parse(s);
                    return (Genre)g;
                }
                catch
                {
                    return Genre.Unknown;
                }
            }
        }

        internal override string GetFrameIdentifier()
        {
            return "TCON";
        }
    }

    internal class ArtistFrame : TextFrame
    {
        public ArtistFrame()
            : base()
        { 
        }

        public ArtistFrame(byte[] data)
            : base(data)
        {
        }

        internal override string GetFrameIdentifier()
        {
            return "TPE2";
        }
    }
}
