// Copyright 2007-2012 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.

using System;
using System.IO;

namespace OpenNETCF.Media.MP3
{
    /// <summary>
    /// Extended Header data from an ID3Tag
    /// </summary>
    /// <remarks>
    /// Currently no extended information parsing is supported.  We simply determine length so we can find data frames in the ID3 Tag.
    /// </remarks>
    internal sealed class ID3ExtendedHeader
    {
        private byte[] m_data;

        private ID3ExtendedHeader(FileStream stream)
        {
            byte[] sizeBytes = new byte[4];
            stream.Read(sizeBytes, 0, 4);

            SynchSafeInteger size = new SynchSafeInteger(sizeBytes, 0);
            m_data = new byte[size.ToInt32()];

            // back up and read the whole extended header
            stream.Seek(-4, SeekOrigin.Current);
            stream.Read(m_data, 0, size.ToInt32());
        }

        public static ID3ExtendedHeader FromStream(FileStream stream)
        {
            return new ID3ExtendedHeader(stream);
        }

        public int Length
        {
            get { return m_data.Length; }
        }
    }
}
